pub fn ensure_running(home: &UnifierHome) -> Result<()>Expand description
Start the daemon if it is not already running (Gradle-style invocation).
pub fn ensure_running(home: &UnifierHome) -> Result<()>Start the daemon if it is not already running (Gradle-style invocation).