Module fs_text

Module fs_text 

Small filesystem helpers for text files and atomic writes.

Functions

read_text
write_text
write_text_atomic
Write to a temp file in the same directory, then rename for atomicity.