Module scope

Module scope 

Path validation: chroot names and subtree confinement.

Functions

path_within_root
True when path is the same as or nested under root.
resolve_under_root
Resolve relative under root, rejecting .. and paths that escape root.
validate_chroot_name
A single path segment safe for use as a chroot name.