Small filesystem helpers for text files and atomic writes.
Functions
- read_
text - write_
text - write_
text_ atomic - Write to a temp file in the same directory, then rename for atomicity.
Small filesystem helpers for text files and atomic writes.